==> image-editor_1.0.11.orig.tar.xz: image-editor-1.0.11/libimageviewer/translations/libimageviewer_pt_BR.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt_BR" version="2.1">
<context>
    <name>ExtensionPanel</name>
    <message>
        <source>Image info</source>
        <translation>Informação da imagem</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation>Ctrl + I</translation>
    </message>
</context>
<context>
    <name>LibImageInfoWidget</name>
    <message>
        <source>Basic info</source>
        <translation>Informação básica</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Detalhes</translation>
    </message>
</context>
<context>
    <name>LibViewPanel</name>
    <message>
        <source>Add to album</source>
        <translation>Adicionar ao álbum</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Novo álbum</translation>
    </message>
    <message>
        <source>All images</source>
        <translation>Todas as imagens</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Abrir Imagem</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exportar</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Remover do álbum</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Remover dos Favoritos</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorito</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>O usuário não tem permissão para visualizar a imagem</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Última modificação</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Tamanho do arquivo</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>Data da captura</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Modo de exposição</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Programa de exposição</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Tempo de exposição</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>Flash</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Abertura</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Distância focal</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Abertura máxima</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Modo de medição</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Balanço de branco</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Compensação de flash</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Modelo da lente</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Espaço de cor</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Modelo da câmera</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>Dimensões</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>Etiqueta</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Back</source>
        <translation>Voltar</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Próximo</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>Escala 1:1 </translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>Ajustar na janela</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>Extrair texto</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Girar no sentido anti-horário</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Girar no sentido horário</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Excluir</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Sair da Tela Cheia</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Tela Cheia</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Imprimir</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Apresentação de Slides</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Renomear</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>Exibir janela de navegação</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>Ocultar janela de navegação</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Definir como papel de parede</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Exibir no Gerenciador de Arquivos</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Informação da imagem</translation>
    </message>
    <message>
        <source>day</source>
        <translation>dia</translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <source>Confirm</source>
        <translation>Confirmar</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Input a new name</source>
        <translation>Digite um novo nome</translation>
    </message>
</context>
<context>
    <name>SlideShowBottomBar</name>
    <message>
        <source>Previous</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausar</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Reproduzir</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Próximo</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Sair</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>Nenhuma imagem encontrada</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>Nenhuma imagem encontrada</translation>
    </message>
    <message>
        <source>You have no permission to view the file</source>
        <translation>Você não tem permissão para ver o arquivo</translation>
    </message>
</context>
</TS>

==> image-editor_1.0.18.orig.tar.xz: image-editor-1.0.18/libimageviewer/translations/libimageviewer_pt_BR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>ExtensionPanel</name>
    <message>
        <source>Image info</source>
        <translation>Informação da imagem</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation>Ctrl + I</translation>
    </message>
</context>
<context>
    <name>LibImageInfoWidget</name>
    <message>
        <source>Basic info</source>
        <translation>Informação básica</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Detalhes</translation>
    </message>
</context>
<context>
    <name>LibViewPanel</name>
    <message>
        <source>Add to album</source>
        <translation>Adicionar ao álbum</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Novo álbum</translation>
    </message>
    <message>
        <source>All images</source>
        <translation>Todas as imagens</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Abrir Imagem</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exportar</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Remover do álbum</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Remover dos Favoritos</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorito</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>O usuário não tem permissão para visualizar a imagem</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Última modificação</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Tamanho do arquivo</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>Data da captura</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Modo de exposição</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Programa de exposição</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Tempo de exposição</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>Flash</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Abertura</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Distância focal</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Abertura máxima</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Modo de medição</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Balanço de branco</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Compensação de flash</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Modelo da lente</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Espaço de cor</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Modelo da câmera</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>Dimensões</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>Etiqueta</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Back</source>
        <translation>Voltar</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Próximo</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>Escala 1:1 </translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>Ajustar na janela</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>Extrair texto</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Girar no sentido anti-horário</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Girar no sentido horário</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Excluir</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Sair da Tela Cheia</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Tela Cheia</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Imprimir</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Apresentação de Slides</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Renomear</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>Exibir janela de navegação</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>Ocultar janela de navegação</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Definir como papel de parede</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Exibir no Gerenciador de Arquivos</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Informação da imagem</translation>
    </message>
    <message>
        <source>day</source>
        <translation>dia</translation>
    </message>
    <message>
        <source>Photo info</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <source>Confirm</source>
        <translation>Confirmar</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Input a new name</source>
        <translation>Digite um novo nome</translation>
    </message>
    <message>
        <source>The file already exists, please use another name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SlideShowBottomBar</name>
    <message>
        <source>Previous</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausar</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Reproduzir</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Próximo</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Sair</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>Nenhuma imagem encontrada</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>Nenhuma imagem encontrada</translation>
    </message>
    <message>
        <source>You have no permission to view the file</source>
        <translation>Você não tem permissão para ver o arquivo</translation>
    </message>
</context>
</TS>
